/*
 * Produce a polynomial matching the input numbers,
 * using a simplified version of the method of divided differences
 */

#include <stdio.h>
#include <math.h>

#define MAX_VALUES	20

int	nValues;
double	value[MAX_VALUES];

int	ReadInput (void);
void	ProducePolynomial (void);

int	main ()
{
	while (ReadInput ())
		ProducePolynomial ();

	return 0;
}

int	ReadInput (void)
{
	char	line[1024], *buf;
	int	pos, i;
	double	num;

	if (!fgets (line, sizeof line, stdin))
		return 0;

	for (i = pos = 0, buf = line;
	     sscanf (buf, "%lf%n", &num, &pos) > 0;
	     i++, buf += pos) {

		if (i >= MAX_VALUES) {
			printf ("Only the first %d numbers were used!\n", i);
			break;
		}
		value[i] = num;
	}

	return nValues = i;
}

void	ProducePolynomial (void)
{
	double	polynomial[MAX_VALUES];
	int	binomial  [MAX_VALUES];
	int	n, i;
	int	first, minus;

	for (i = 0; i < nValues; i++)
		polynomial[i] = binomial[i] = 0;

	polynomial[0] = value[0];
	binomial  [0] = 1;

	for (n = 1; n < nValues; n++) {

		for (i = nValues; --i >= n;)
			value[i] = (value[i] - value[i - 1]) / n;

		for (i = n; i > 0; i--) {
			binomial[i] = -(n - 1) * binomial[i] + binomial[i - 1];

			polynomial[i] += binomial[i] * value[n];
		}
		binomial[0] = 0;
	}

	/* printout */

	first = 1;
	printf ("\t");

	for (i = nValues; --i >= 0;) {
		if (fabs (polynomial[i]) < 1e-20)
			continue;

		minus = polynomial[i] < 0;
		polynomial[i] = fabs (polynomial[i]);

		if (minus)
			printf (" - ");
		else if (!first)
			printf (" + ");
		first = 0;

		if (i == 0 || fabs (polynomial[i] - 1) > 1e-20)
			printf ("%g", polynomial[i]);

		if (i > 0) {
			printf ("n");
			if (i > 1)
				printf ("^%d", i);
		}
	}
	printf (" ,  n=0..%d\n", nValues - 1);
}
